@@ -17,13 +17,23 @@ class Cpu(checks.AgentCheck):
         """
         dimensions = self._set_dimensions(None, instance)
 
+        if instance is not None:
+            send_rollup_stats =  instance.get("send_rollup_stats", False)
+        else:
+            send_rollup_stats =  False
+
         cpu_stats = psutil.cpu_times_percent(percpu=False)
-        self._format_results(cpu_stats.user + cpu_stats.nice,
-                             cpu_stats.system + cpu_stats.irq + cpu_stats.softirq,
-                             cpu_stats.iowait,
-                             cpu_stats.idle,
-                             cpu_stats.steal,
-                             dimensions)
+        num_of_metrics = self._format_results(cpu_stats.user + cpu_stats.nice,
+                                              cpu_stats.system + cpu_stats.irq + cpu_stats.softirq,
+                                              cpu_stats.iowait,
+                                              cpu_stats.idle,
+                                              cpu_stats.steal,
+                                              dimensions)
+        if send_rollup_stats:
+            self.gauge('cpu.total_logical_cores', psutil.cpu_count(logical=True), dimensions)
+            num_of_metrics += 1
+        log.debug('Collected {0} cpu metrics'.format(num_of_metrics))
+
 
     def _format_results(self, us, sy, wa, idle, st, dimensions):
         data = {'cpu.user_perc': us,
@@ -38,4 +48,4 @@ class Cpu(checks.AgentCheck):
 
         [self.gauge(key, value, dimensions) for key, value in data.iteritems()]
 
-        log.debug('Collected {0} cpu metrics'.format(len(data)))
+        return len(data)
