@@ -65,7 +65,8 @@ class LibvirtCheck(AgentCheck):
                                     self.init_config.get('admin_password'),
                                     self.init_config.get('admin_tenant_name'),
                                     self.init_config.get('identity_uri'),
-                                    service_type="compute")
+                                    service_type="compute",
+                                    region_name=self.init_config.get('region_name'))
         instances = nova_client.servers.list(search_opts={'all_tenants': 1})
 
         for instance in instances:
